const shell = require('shelljs')
const symbols = require('log-symbols')
const clone = require('../utils/clone.js')
// const inquirer = require('inquirer')
const ora = require('ora')
const chalk = require('chalk')
const path = require('path')
const fs = require('fs')

const remote = 'https://gitee.com/xianyoudamo/hzero-front-dva.git'
let branch = 'master'

const initAction = async (name, option) => {
  // 0. 检查控制台是否可以运行`git `，
  if (!shell.which('git')) {
    console.log(symbols.error, '对不起，git命令不可用！')
    shell.exit(1)
  }
  // 1. 验证输入name是否合法
  if (fs.existsSync(name)) {
    console.log(symbols.warning, `已存在项目文件夹${name}！`)
    return
  }
  if (name.match(/[^A-Za-z0-9\u4e00-\u9fa5_-]/g)) {
    console.log(symbols.error, '项目名称存在非法字符！')
    return
  }
  // 2. 获取option，确定模板类型（分支）
  if (option.dev) branch = 'develop'
  // 3. 定义需要询问的问题
  // const questions = [
  //   {
  //     type: 'input',
  //     message: '请输入项目名称:',
  //     name: 'name',
  //     validate(val) {
  //       if (!val) return '项目名称不能为空！'
  //       if (val.match(/[^A-Za-z0-9\u4e00-\u9fa5_-]/g))
  //         return '项目名称包含非法字符，请重新输入'
  //       return true
  //     },
  //   },
  // ]
  // // 通过inquirer获取到用户输入的内容
  // const answers = await inquirer.prompt(questions)
  // // 将用户的配置打印，确认一下是否正确
  // console.log('------------------------')
  // console.log(answers)
  // let confirm = await inquirer.prompt([
  //   {
  //     type: 'confirm',
  //     message: '确认创建？',
  //     default: 'Y',
  //     name: 'isConfirm',
  //   },
  // ])
  // if (!confirm.isConfirm) return false
  // 4. 下载模板
  await clone(`direct:${remote}#${branch}`, path.resolve(packages, name), {
    clone: true,
  })
  // 5. 清理文件
  const deleteDir = ['.git', 'README.md', 'docs'] // 需要清理的文件
  const pwd = shell.pwd()
  deleteDir.map((item) => shell.rm('-rf', pwd + `/${name}/${item}`))
  // 6. 安装依赖
  const installSpinner = ora('正在安装依赖...').start()
  if (shell.exec('npm install').code !== 0) {
    console.log(symbols.warning, chalk.yellow('自动安装失败，请手动安装！'))
    installSpinner.fail() // 安装失败
    shell.exit(1)
  }
  installSpinner.succeed(chalk.green('依赖安装成功！'))
}

module.exports = initAction
